import type middy from '@middy/core';
import type { Tracer } from '../Tracer';
import type { HandlerOptions } from '../types';
/**
 * A middy middleware automating capture of metadata and annotations on segments or subsegments for a Lambda Handler.
 *
 * Using this middleware on your handler function will automatically:
 * * handle the subsegment lifecycle
 * * add the `ColdStart` annotation
 * * add the function response as metadata
 * * add the function error as metadata (if any)
 *
 * @example
 * ```typescript
 * import { Tracer, captureLambdaHandler } from '@aws-lambda-powertools/tracer';
 * import middy from '@middy/core';
 *
 * const tracer = new Tracer({ serviceName: 'serverlessAirline' });
 *
 * export const handler = middy(async (_event: any, _context: any) => {
 *   ...
 * }).use(captureLambdaHandler(tracer));
 * ```
 *
 * @param target - The Tracer instance to use for tracing
 * @returns middleware object - The middy middleware object
 */
declare const captureLambdaHandler: (target: Tracer, options?: HandlerOptions | undefined) => middy.MiddlewareObj;
export { captureLambdaHandler, };
//# sourceMappingURL=middy.d.ts.map